@@ -135,29 +135,30 @@ class GitIssuePublisher(Publisher):
 
     def generate_report(self, data):
         report = [
-            f"### Commit Review Summary [{self.sha}]\n",
-            f"**Author:** {self.user}\n",
-            f"**Message:**\n",
-            f"- **Provided:** {data['message']['provided']}",
-            f"- **Generated:** {data['message']['generated']}\n",
-            f"- **Adherence Score:** {data['message']['adherence']['score']} {data['message']['adherence']['emoji']}",
-            f"  *{data['message']['adherence']['comment']}*\n",
-            "\n**Code Complexity:**\n",
-            f"- **Comment:** {data['codeComplexity']['comment']}\n",
-            "\n**Code Vulnerability:**\n",
-            f"- **Score:** {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']}",
-            f"  *{data['codeVulnerability']['comment']}*\n",
-            "\n**SOLID Principles Analysis:**\n"
+            f"## Commit Review Summary [{self.sha}]",
+            "| **Author** | **Provided Message** | **Generated Message** | **Adherence Score** | **Comment** |",
+            "|------------|----------------------|-----------------------|---------------------|-------------|",
+            f"| {self.user} | '{data['message']['provided']}' | '{data['message']['generated']}' | {data['message']['adherence']['score']} {data['message']['adherence']['emoji']} | *{data['message']['adherence']['comment']}* |",
+            "\n### Code Complexity",
+            "| **Complexity Comment** |",
+            "|------------------------|",
+            f"| {data['codeComplexity']['comment']} |",
+            "\n### Code Vulnerability",
+            "| **Score** | **Comment** |",
+            "|-----------|-------------|",
+            f"| {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']} | {data['codeVulnerability']['comment']} |",
+            "\n### SOLID Principles",
+            "| **Principle** | **Score** | **Comment** |",
+            "|----------------|-----------|-------------|"
         ]
 
         for principle, details in data['codeSOLID'].items():
-            report.append(f"- **{principle.replace('_', ' ').title()}**")
-            report.append(f"  - **Score:** {details['score']} {details['emoji']}")
-            report.append(f"  *{details['comment']}*\n")
-
+            principle_name = principle.replace('_', ' ').title()
+            report.append(f"| {principle_name} | {details['score']} {details['emoji']} | {details['comment']} |")
 
         return '\n'.join(report)
 
+
     def generate_issue(self, existing_body: str, **scores) -> str:
         """
         Appends adherence data to the existing comment body using a Mermaid XY diagram.
